#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class IgesSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         IgesSettingAtt
                | 
                | Represents the CATIA IGES setting controller object.
                | Role: The CATIA IGES setting controller object deals with the setting
                | attributes displayed in the IGES property page. To access this property
                | page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of General to unfold the workbench list
                |     Click Compatibility
                |     Right scroll to display the property pages titles until you get
                |     IGES
                |     Click IGES
                | 
                | The New Elements setting controller object can be retrieved as an item of the
                | setting controller collection using its name "CAACafNewEltSettingCtrl" as
                | follows:
                | 
                |  Dim settingControllers1 As SettingControllers
                |  Set settingControllers1 = CATIA.SettingControllers
                |  Dim CATIAIGESSettingAtt1 As SettingController
                |  Set CATIAIGESSettingAtt1 = settingControllers1.Item("CATIdeIgesSettingCtrl")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.iges_setting_att = com_object

    @property
    def angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Angle() As double
                | 
                |     Returns or sets the Angle setting parameter value.
                |     Role: The Angle setting parameter manages the maximal angle of
                |     deformation.
                | 
                |     Parameters:
                | 
                |         oAngle
                |             [out] The Angle parameter value
                |             Legal values: value of angle in degree, between 0.0 and 10.0
                |             deg.

        :rtype: float
        """

        return self.iges_setting_att.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.iges_setting_att.Angle = value

    @property
    def apply_join(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ApplyJoin() As long
                | 
                |     Returns or sets the Apply join setting parameter value.
                |     Role: The XXX setting parameter manages the Apply Join
                |     mode
                | 
                |     Parameters:
                | 
                |         oApplyJoin
                |             [out] The Apply join parameter value
                |             Legal values: 1 To Apply Join on faces, 0
                |             otherwise.

        :rtype: int
        """

        return self.iges_setting_att.ApplyJoin

    @apply_join.setter
    def apply_join(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.ApplyJoin = value

    @property
    def author_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AuthorName() As CATBSTR
                | 
                |     Returns or sets the Author Name setting parameter value.
                |     Role: The Author Name setting parameter manages the Author
                |     Name.
                | 
                |     Parameters:
                | 
                |         oAuthorName
                |             [out] The Author Name parameter value
                |             Legal values: (any text).

        :rtype: str
        """

        return self.iges_setting_att.AuthorName

    @author_name.setter
    def author_name(self, value: str):
        """
        :param str value:
        """

        self.iges_setting_att.AuthorName = value

    @property
    def author_organization(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AuthorOrganization() As CATBSTR
                | 
                |     Returns or sets the Author Organization setting parameter
                |     value.
                |     Role: The Author Organization setting parameter manages the Author
                |     Organization.
                | 
                |     Parameters:
                | 
                |         oAuthorOrganization
                |             [out] The Author Organization parameter value
                |             Legal values: (any text).

        :rtype: str
        """

        return self.iges_setting_att.AuthorOrganization

    @author_organization.setter
    def author_organization(self, value: str):
        """
        :param str value:
        """

        self.iges_setting_att.AuthorOrganization = value

    @property
    def crv_mod(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CrvMod() As long
                | 
                |     Returns or sets the Export BSpline mode setting parameter
                |     value.
                |     Role: The Export BSpline mode setting parameter manages the mode to export
                |     curves and surfaces
                | 
                |     Parameters:
                | 
                |         oCrvMod
                |             [out] The Export BSpline mode parameter value
                |             Legal values:
                |                 0 for standard mode;
                |                 1 for BSpline mode : all curves and surfaces will be exported
                |                                      as B-Spline curves and surfaces.

        :rtype: int
        """

        return self.iges_setting_att.CrvMod

    @crv_mod.setter
    def crv_mod(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.CrvMod = value

    @property
    def export_msbo(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportMSBO() As long
                | 
                |     Returns or sets the Export Solid Mode setting parameter
                |     value.
                |     Role: The Export Solid Mode setting parameter manages the export of solids
                |     and shells
                | 
                |     Parameters:
                | 
                |         oExportMSBO
                |             [out] The Export Solid Mode parameter value
                |             Legal values: 1 to export solids and shells as 186/514 IGES
                |             entities, 0 to export them as trimmed surfaces.

        :rtype: int
        """

        return self.iges_setting_att.ExportMSBO

    @export_msbo.setter
    def export_msbo(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.ExportMSBO = value

    @property
    def export_unit(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportUnit() As long
                | 
                |     Returns or sets the Export Units setting parameter value.
                |     Role: The Export Units setting parameter manages the unit in exported IGES
                |     Files.
                | 
                |     Parameters:
                | 
                |         oExportUnit
                |             [out] The Export Units parameter value
                |             Legal values: 0-10 :
                |                 0 : user unit;
                |                 1 : Inches;
                |                 2 : Millimeters;
                |                 3 : Feet;
                |                 4 : Miles;
                |                 5 : Meters;
                |                 6 : Kilometers;
                |                 7 : Mils;
                |                 8 : Microns;
                |                 9 : Centimeters;
                |                10 : Microinches.

        :rtype: int
        """

        return self.iges_setting_att.ExportUnit

    @export_unit.setter
    def export_unit(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.ExportUnit = value

    @property
    def import_group_as_sel_set(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportGroupAsSelSet() As long
                | 
                |     Returns or sets the Import Selection Set mode setting parameter
                |     value.
                |     Role: The Import Selection Set mode setting parameter manages the Import of
                |     IGES groups.
                | 
                |     Parameters:
                | 
                |         oImportGroupAsSelSet
                |             [out] The Import Selection Set mode parameter
                |             value
                |             Legal values:
                |                 1 To map IGES Groups as Selection Sets,
                |                 0 otherwise.

        :rtype: int
        """

        return self.iges_setting_att.ImportGroupAsSelSet

    @import_group_as_sel_set.setter
    def import_group_as_sel_set(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.ImportGroupAsSelSet = value

    @property
    def only_show(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OnlyShow() As long
                | 
                |     Returns or sets the Export only show setting parameter
                |     value.
                |     Role: The Export only show setting parameter manages the mode to export
                |     entities in No-Show
                | 
                |     Parameters:
                | 
                |         oOnlyShow
                |             [out] The Export only show parameter value
                |             Legal values: 1 to export only visible elements, 0 to export
                |             visible and invisible elements.

        :rtype: int
        """

        return self.iges_setting_att.OnlyShow

    @only_show.setter
    def only_show(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.OnlyShow = value

    @property
    def opt_c2_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OptC2Mode() As long
                | 
                |     Returns or sets the Continuity Optimization Mode setting parameter
                |     value.
                |     Role: The Continuity Optimization Mode setting parameter manages the
                |     ...
                | 
                |     Parameters:
                | 
                |         oOptC2Mode
                |             [out] The Continuity Optimization Mode parameter
                |             value
                |             Legal values: 0 to Disable Optimize Continuity ; 1 to Enable
                |             default Optimize Continuity 2 to Enable Advanced Optimize
                |             Continuity.

        :rtype: int
        """

        return self.iges_setting_att.OptC2Mode

    @opt_c2_mode.setter
    def opt_c2_mode(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.OptC2Mode = value

    @property
    def opt_clean_topo_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OptCleanTopoMode() As long
                | 
                |     Returns or sets the clean topo mode setting parameter
                |     value.
                |     Role: The clean topo mode setting parameter manages the the Fitting Mode,
                |     in Advanced Optimize Continuity Mode.
                | 
                |     Parameters:
                | 
                |         oOptCleanTopoMode
                |             [out] The clean topo mode parameter value
                |             Legal values: 0 to Disable the clean topo Mode, 1 to Enable the
                |             clean topo Mode.

        :rtype: int
        """

        return self.iges_setting_att.OptCleanTopoMode

    @opt_clean_topo_mode.setter
    def opt_clean_topo_mode(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.OptCleanTopoMode = value

    @property
    def opt_fitting_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OptFittingMode() As long
                | 
                |     Returns or sets the Fitting Mode setting parameter value.
                |     Role: The Fitting Mode setting parameter manages the Fitting Mode, in
                |     Advanced Optimize Continuity Mode.
                | 
                |     Parameters:
                | 
                |         oOptFittingMode
                |             [out] The Fitting Mode parameter value
                |             Fitting Mode values: 0 to Disable the Fitting Mode, 1 to Enable the
                |             Fitting Mode.

        :rtype: int
        """

        return self.iges_setting_att.OptFittingMode

    @opt_fitting_mode.setter
    def opt_fitting_mode(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.OptFittingMode = value

    @property
    def opt_invalid_geom_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OptInvalidGeomMode() As long
                | 
                |     Returns or sets the InvalidGeom mode setting parameter
                |     value.
                |     Role: The InvalidGeom mode setting parameter manages the Invalid Geometry
                |     Checks.
                | 
                |     Parameters:
                | 
                |         oOptInvalidGeomMode
                |             [out] The InvalidGeom mode parameter value
                |             Legal values: 0 to disable Invalid Geometry Checks, 1 to enable
                |             it.

        :rtype: int
        """

        return self.iges_setting_att.OptInvalidGeomMode

    @opt_invalid_geom_mode.setter
    def opt_invalid_geom_mode(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.OptInvalidGeomMode = value

    @property
    def opt_loop3_d_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OptLoop3DMode() As long
                | 
                |     Returns or sets the Force 3D Loop setting parameter value.
                |     Role: The Force 3D Loop setting parameter manages the Import of IGES
                |     boundaries, to use only the 3D representation.
                | 
                |     Parameters:
                | 
                |         oOptLoop3DMode
                |             [out] The Force 3D Loop parameter value
                |             Legal values: 0 to keep file preference, 1 to Force the use of 3D
                |             representation.

        :rtype: int
        """

        return self.iges_setting_att.OptLoop3DMode

    @opt_loop3_d_mode.setter
    def opt_loop3_d_mode(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.OptLoop3DMode = value

    @property
    def part_prod_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PartProdMode() As long
                | 
                |     Returns or sets the Import Product mode setting parameter
                |     value.
                |     Role: The Import Product mode setting parameter manages the Product mode
                |     for Import of 308/408 IGES entities.
                | 
                |     Parameters:
                | 
                |         oPartProdMode
                |             [out] The Import Product mode parameter value
                |             Legal values: 0 to import 308/408 in a CATPart, 1 to create a
                |             Product Structure.

        :rtype: int
        """

        return self.iges_setting_att.PartProdMode

    @part_prod_mode.setter
    def part_prod_mode(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.PartProdMode = value

    @property
    def rep_mod(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RepMod() As long
                | 
                |     Returns or sets the Export representation mode setting parameter
                |     value.
                |     Role: The Export representation mode setting parameter manages the export
                |     of faces as surfaces or as wireframe.
                | 
                |     Parameters:
                | 
                |         oRepMod
                |             [out] The Export representation mode parameter
                |             value
                |             Legal values: 1 to export surfaces as wireframes, 0
                |             otherwise.

        :rtype: int
        """

        return self.iges_setting_att.RepMod

    @rep_mod.setter
    def rep_mod(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.RepMod = value

    @property
    def show_completion_dialog_box(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShowCompletionDialogBox() As long
                | 
                |     Returns or sets the Show/No Show dialog box setting parameter
                |     value.
                |     Role: The Show/No Show dialog box setting parameter manages the visibility
                |     of the Completion dialog box.
                |     Legal values: 1 to show, and 0 to hide the Show/No Show dialog box.

        :rtype: int
        """

        return self.iges_setting_att.ShowCompletionDialogBox

    @show_completion_dialog_box.setter
    def show_completion_dialog_box(self, value: int):
        """
        :param int value:
        """

        self.iges_setting_att.ShowCompletionDialogBox = value

    @property
    def tol_join(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TolJoin() As double
                | 
                |     Returns or sets the join tolerance setting parameter
                |     value.
                |     Role: The join tolerance setting parameter manages the Tolerance for
                |     Join
                | 
                |     Parameters:
                | 
                |         oTolJoin
                |             [out] The join tolerance parameter value
                |             Legal values: Value of tolerance in mm, between 0.0 and 0.1
                |             mm.

        :rtype: float
        """

        return self.iges_setting_att.TolJoin

    @tol_join.setter
    def tol_join(self, value: float):
        """
        :param float value:
        """

        self.iges_setting_att.TolJoin = value

    @property
    def tol_opt_invalid_geom(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TolOptInvalidGeom() As double
                | 
                |     Returns or sets the InvalidGeom Tolerance setting parameter
                |     value.
                |     Role: The InvalidGeom Tolerance setting parameter manages the Tolerance for
                |     invalid geometry checks.
                | 
                |     Parameters:
                | 
                |         oTolOptInvalidGeom
                |             [out] The InvalidGeom Tolerance parameter value
                |             Legal values: value of tolerance, in mm, between 0.5 and 20
                |             mm.

        :rtype: float
        """

        return self.iges_setting_att.TolOptInvalidGeom

    @tol_opt_invalid_geom.setter
    def tol_opt_invalid_geom(self, value: float):
        """
        :param float value:
        """

        self.iges_setting_att.TolOptInvalidGeom = value

    @property
    def tolerance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Tolerance() As double
                | 
                |     Returns or sets the tolerance ( optimize - fitting ) setting parameter
                |     value.
                |     Role: The tolerance ( optimize - fitting ) setting parameter manages the
                |     tolerance for Optimize continuity and Fitting.
                | 
                |     Parameters:
                | 
                |         oTolerance
                |             [out] The tolerance ( optimize - fitting ) parameter
                |             value
                |             Legal values: value of tolerance in mm, between 0.0005 and 0.10
                |             mm.

        :rtype: float
        """

        return self.iges_setting_att.Tolerance

    @tolerance.setter
    def tolerance(self, value: float):
        """
        :param float value:
        """

        self.iges_setting_att.Tolerance = value

    def get_angle_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAngleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Angle setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetAngleInfo(io_admin_level, io_locked)

    def get_apply_join_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetApplyJoinInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Apply Join setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetApplyJoinInfo(io_admin_level, io_locked)

    def get_author_name_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAuthorNameInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AuthorName
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetAuthorNameInfo(io_admin_level, io_locked)

    def get_author_organization_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAuthorOrganizationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AuthorOrganization
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetAuthorOrganizationInfo(io_admin_level, io_locked)

    def get_crv_mod_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCrvModInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Export BSpline mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetCrvModInfo(io_admin_level, io_locked)

    def get_export_msbo_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportMSBOInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Export Solid Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetExportMSBOInfo(io_admin_level, io_locked)

    def get_export_unit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportUnitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Export Units setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetExportUnitInfo(io_admin_level, io_locked)

    def get_import_group_as_sel_set_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportGroupAsSelSetInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Import Selection Set mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetImportGroupAsSelSetInfo(io_admin_level, io_locked)

    def get_only_show_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOnlyShowInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Export only show setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetOnlyShowInfo(io_admin_level, io_locked)

    def get_opt_c2_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOptC2ModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Continuity Optimization Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetOptC2ModeInfo(io_admin_level, io_locked)

    def get_opt_clean_topo_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOptCleanTopoModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Clean Topo Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetOptCleanTopoModeInfo(io_admin_level, io_locked)

    def get_opt_fitting_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOptFittingModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Fitting Mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetOptFittingModeInfo(io_admin_level, io_locked)

    def get_opt_invalid_geom_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOptInvalidGeomModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the InvalidGeom mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetOptInvalidGeomModeInfo(io_admin_level, io_locked)

    def get_opt_loop3_d_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOptLoop3DModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Force 3D Loop setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetOptLoop3DModeInfo(io_admin_level, io_locked)

    def get_part_prod_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPartProdModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Import Product mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetPartProdModeInfo(io_admin_level, io_locked)

    def get_rep_mod_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRepModInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Export representation mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetRepModInfo(io_admin_level, io_locked)

    def get_show_completion_dialog_box_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetShowCompletionDialogBoxInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Show/No Show dialog box setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetShowCompletionDialogBoxInfo(io_admin_level, io_locked)

    def get_tol_join_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTolJoinInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the join tolerance setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetTolJoinInfo(io_admin_level, io_locked)

    def get_tol_opt_invalid_geom_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTolOptInvalidGeomInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the InvalidGeom Tolerance setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetTolOptInvalidGeomInfo(io_admin_level, io_locked)

    def get_tolerance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetToleranceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Tolerance ( optimize - fitting ) setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.iges_setting_att.GetToleranceInfo(io_admin_level, io_locked)

    def set_angle_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAngleLock(boolean iLocked)
                | 
                |     Locks or unlocks the Angle setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetAngleLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_angle_lock'
        # # vba_code = """
        # # Public Function set_angle_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetAngleLock iLocked
        # #     set_angle_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_apply_join_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetApplyJoinLock(boolean iLocked)
                | 
                |     Locks or unlocks the Apply Join setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetApplyJoinLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_apply_join_lock'
        # # vba_code = """
        # # Public Function set_apply_join_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetApplyJoinLock iLocked
        # #     set_apply_join_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_author_name_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAuthorNameLock(boolean iLocked)
                | 
                |     Locks or unlocks the AuthorName parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetAuthorNameLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_author_name_lock'
        # # vba_code = """
        # # Public Function set_author_name_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetAuthorNameLock iLocked
        # #     set_author_name_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_author_organization_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAuthorOrganizationLock(boolean iLocked)
                | 
                |     Locks or unlocks the AuthorOrganization parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetAuthorOrganizationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_author_organization_lock'
        # # vba_code = """
        # # Public Function set_author_organization_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetAuthorOrganizationLock iLocked
        # #     set_author_organization_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_crv_mod_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCrvModLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export BSpline mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetCrvModLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_crv_mod_lock'
        # # vba_code = """
        # # Public Function set_crv_mod_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetCrvModLock iLocked
        # #     set_crv_mod_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_msbo_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportMSBOLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Solid Mode setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetExportMSBOLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_msbo_lock'
        # # vba_code = """
        # # Public Function set_export_msbo_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetExportMSBOLock iLocked
        # #     set_export_msbo_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_unit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportUnitLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Units setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetExportUnitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_unit_lock'
        # # vba_code = """
        # # Public Function set_export_unit_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetExportUnitLock iLocked
        # #     set_export_unit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_group_as_sel_set_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportGroupAsSelSetLock(boolean iLocked)
                | 
                |     Locks or unlocks the Import Selection Set mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetImportGroupAsSelSetLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_group_as_sel_set_lock'
        # # vba_code = """
        # # Public Function set_import_group_as_sel_set_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetImportGroupAsSelSetLock iLocked
        # #     set_import_group_as_sel_set_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_only_show_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOnlyShowLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export only show setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetOnlyShowLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_only_show_lock'
        # # vba_code = """
        # # Public Function set_only_show_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetOnlyShowLock iLocked
        # #     set_only_show_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_opt_c2_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOptC2ModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Continuity Optimizationmode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetOptC2ModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_opt_c2_mode_lock'
        # # vba_code = """
        # # Public Function set_opt_c2_mode_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetOptC2ModeLock iLocked
        # #     set_opt_c2_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_opt_clean_topo_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOptCleanTopoModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Clean Topo Mode setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetOptCleanTopoModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_opt_clean_topo_mode_lock'
        # # vba_code = """
        # # Public Function set_opt_clean_topo_mode_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetOptCleanTopoModeLock iLocked
        # #     set_opt_clean_topo_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_opt_fitting_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOptFittingModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Fitting Mode setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetOptFittingModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_opt_fitting_mode_lock'
        # # vba_code = """
        # # Public Function set_opt_fitting_mode_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetOptFittingModeLock iLocked
        # #     set_opt_fitting_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_opt_invalid_geom_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOptInvalidGeomModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the InvalidGeom mode setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetOptInvalidGeomModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_opt_invalid_geom_mode_lock'
        # # vba_code = """
        # # Public Function set_opt_invalid_geom_mode_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetOptInvalidGeomModeLock iLocked
        # #     set_opt_invalid_geom_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_opt_loop3_d_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOptLoop3DModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Force 3D Loop setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetOptLoop3DModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_opt_loop3_d_mode_lock'
        # # vba_code = """
        # # Public Function set_opt_loop3_d_mode_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetOptLoop3DModeLock iLocked
        # #     set_opt_loop3_d_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_part_prod_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPartProdModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Import Product mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetPartProdModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_part_prod_mode_lock'
        # # vba_code = """
        # # Public Function set_part_prod_mode_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetPartProdModeLock iLocked
        # #     set_part_prod_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rep_mod_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRepModLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export representation mode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetRepModLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rep_mod_lock'
        # # vba_code = """
        # # Public Function set_rep_mod_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetRepModLock iLocked
        # #     set_rep_mod_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_show_completion_dialog_box_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetShowCompletionDialogBoxLock(boolean iLocked)
                | 
                |     Locks or unlocks the Show/No Show dialog box setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetShowCompletionDialogBoxLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_show_completion_dialog_box_lock'
        # # vba_code = """
        # # Public Function set_show_completion_dialog_box_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetShowCompletionDialogBoxLock iLocked
        # #     set_show_completion_dialog_box_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tol_join_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTolJoinLock(boolean iLocked)
                | 
                |     Locks or unlocks the join tolerance setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetTolJoinLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tol_join_lock'
        # # vba_code = """
        # # Public Function set_tol_join_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetTolJoinLock iLocked
        # #     set_tol_join_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tol_opt_invalid_geom_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTolOptInvalidGeomLock(boolean iLocked)
                | 
                |     Locks or unlocks the InvalidGeom Tolerance setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetTolOptInvalidGeomLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tol_opt_invalid_geom_lock'
        # # vba_code = """
        # # Public Function set_tol_opt_invalid_geom_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetTolOptInvalidGeomLock iLocked
        # #     set_tol_opt_invalid_geom_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tolerance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetToleranceLock(boolean iLocked)
                | 
                |     Locks or unlocks the Tolerance ( optimize - fitting ) setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :rtype: None
        """
        return self.iges_setting_att.SetToleranceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tolerance_lock'
        # # vba_code = """
        # # Public Function set_tolerance_lock(iges_setting_att)
        # #     Dim iLocked (2)
        # #     iges_setting_att.SetToleranceLock iLocked
        # #     set_tolerance_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'IgesSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.assembly_interfaces.assembly_feature import AssemblyFeature
from pycatia.in_interfaces.reference import Reference
from pycatia.part_interfaces.limit import Limit
from pycatia.product_structure_interfaces.product import Product
from pycatia.sketcher_interfaces.sketch import Sketch


class AssemblyPocket(AssemblyFeature):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATAssemblyInterfaces.AssemblyFeature
                |                         AssemblyPocket
                | 
                | Represents the AssemblyPocket object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.assembly_pocket = com_object

    @property
    def direction_orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DirectionOrientation() As CatPrismOrientation
                | 
                |     Returns or sets the pocket direction orientation.
                | 
                |     Example:
                |         The following example saves in dirOrientation the direction orientation
                |         of the pocket assemblyPocket, and then sets it so that the direction will be
                |         now inversed.
                | 
                |          Dim dirOrientation
                |          Set dirOrientation = assemblyPocket.DirectionOrientation
                |          assemblyPocket.DirectionOrientation = catInverseOrientation

        :return: enum cat_prism_orientation
        :rtype: int
        """

        return self.assembly_pocket.DirectionOrientation

    @direction_orientation.setter
    def direction_orientation(self, value: int):
        """
        :param int value: enum cat_prism_orientation
        """

        self.assembly_pocket.DirectionOrientation = value

    @property
    def direction_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DirectionType() As CatPrismExtrusionDirection
                | 
                |     Returns or sets the pocket direction type.
                | 
                |     Example:
                |         The following example saves in dirType the direction type of the pocket
                |         assemblyPocket, and then sets it so that the direction will be now normal to
                |         the sketch.
                | 
                |          Dim dirType
                |          Set dirType = assemblyPocket.DirectionType
                |          assemblyPocket.DirectionType = catNormalToSketchDirection

        :return: enum cat_prism_extrusion_direction
        :rtype: int
        """

        return self.assembly_pocket.DirectionType

    @direction_type.setter
    def direction_type(self, value: int):
        """
        :param int value: enum cat_prism_extrusion_direction
        """

        self.assembly_pocket.DirectionType = value

    @property
    def first_limit(self) -> Limit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FirstLimit() As Limit (Read Only)
                | 
                |     Returns the first pocket limit.
                |     A pocket has two limits that manage the way the pocket is
                |     ended.
                | 
                |     Example:
                |         The following example returns in firstLimit the first limit of the
                |         pocket assemblyPocket.
                | 
                |          Dim firstLimit As Limit
                |          Set firstLimit = assemblyPocket.FirstLimit

        :rtype: Limit
        """

        return Limit(self.assembly_pocket.FirstLimit)

    @property
    def is_symmetric(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsSymmetric() As boolean
                | 
                |     Returns or sets the pocket symmetry flag.
                |     TRUE if the pocket is symmetric with respect to the base sketch, and FALSE
                |     otherwise.
                | 
                |     Example:
                |         The following example saves in symFlag the symmetry flag of the pocket
                |         assemblyPocket, and then sets it so that it will be now symmetric with respect
                |         to the base sketch.
                | 
                |          Dim symFlag As boolean
                |          Set symFlag = assemblyPocket.IsSymmetric
                |          assemblyPocket.IsSymmetric = TRUE

        :rtype: bool
        """

        return self.assembly_pocket.IsSymmetric

    @is_symmetric.setter
    def is_symmetric(self, value: bool):
        """
        :param bool value:
        """

        self.assembly_pocket.IsSymmetric = value

    @property
    def second_limit(self) -> Limit:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SecondLimit() As Limit (Read Only)
                | 
                |     Returns the second pocket limit.
                |     A pocket has two limits that manage the way the pocket is
                |     ended.
                | 
                |     Example:
                |         The following example returns in secondLimit the second limit of the
                |         pocket assemblyPocket.
                | 
                |          Dim secondLimit As Limit
                |          Set secondLimit = assemblyPocket.SecondLimit

        :rtype: Limit
        """

        return Limit(self.assembly_pocket.SecondLimit)

    @property
    def sketch(self) -> Sketch:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Sketch() As Sketch (Read Only)
                | 
                |     Returns the pocket sketch.
                | 
                |     Example:
                |         The following example retrieves in sketch the sketch on which the
                |         pocket assemblyPocket is built.
                | 
                |          Dim sketch As Sketch
                |          Set sketch = assemblyPocket.Sketch

        :rtype: Sketch
        """

        return Sketch(self.assembly_pocket.Sketch)

    @property
    def sketch_component(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SketchComponent() As Product (Read Only)
                | 
                |     Returns the component containing the pocket sketch.
                | 
                |     Example:
                |         The following example retrieves in skComp the component that contains
                |         the sketch of the pocket assemblyPocket is built.
                | 
                |          Dim skComp As Product
                |          Set skComp = assemblyPocket.SketchComponent

        :rtype: Product
        """

        return Product(self.assembly_pocket.SketchComponent)

    def get_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDirection(CATSafeArrayVariant ioDirection)
                | 
                |     Retrieves the pocket direction vector components.
                |     These components are expressed in millimeter according to the absolute
                |     coordinate system.
                | 
                |     Parameters:
                | 
                |         ioDirection
                |             The pocket direction vector components, as a safe array made up of
                |             three doubles: X, Y, Z
                |             The array must be previously initialized. 
                | 
                |     Example:
                |         The following example retrieves in dirArray the direction vector
                |         components of the pocket assemblyPocket.
                | 
                |          Dim dirArray(2)
                |          Call assemblyPocket.GetDirection(dirArray)
                |          Set x = dirArray[0]
                |          Set y = dirArray[1]
                |          Set z = dirArray[2]

        :param tuple io_direction:
        :rtype: None
        """
        return self.assembly_pocket.GetDirection()
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_direction'
        # # vba_code = """
        # # Public Function get_direction(assembly_pocket)
        # #     Dim ioDirection (2)
        # #     assembly_pocket.GetDirection ioDirection
        # #     get_direction = ioDirection
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reverse_inner_side(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReverseInnerSide()
                | 
                |     Reverses the pocket inner side when the profile is open.
                |     This is useful for finding the shape to reach.
                | 
                |     Example:
                |         The following example reverses the current inner side of the pocket
                |         assemblyPocket.
                | 
                |          assemblyPocket.ReverseInnerSide

        :rtype: None
        """
        return self.assembly_pocket.ReverseInnerSide()

    def set_direction(self, i_line: Reference, i_line_comp: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDirection(Reference iLine,
                | Product iLineComp)
                | 
                |     Sets the pocket associated direction.
                | 
                |     Parameters:
                | 
                |         iLine
                |             The pocket associated direction, as a reference to a line or an
                |             edge. 
                |         iLineComp
                |             The component containing the associated direction
                |             reference
                | 
                |             Example:
                |                 The following example sets the associated direction of the
                |                 pocket assemblyPocket using the dirRef line of the component
                |                 dirComp.
                | 
                |                  assemblyPocket.SetDirection dirRef, dirComp

        :param Reference i_line:
        :param Product i_line_comp:
        :rtype: None
        """
        return self.assembly_pocket.SetDirection(i_line.com_object, i_line_comp.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_direction'
        # # vba_code = """
        # # Public Function set_direction(assembly_pocket)
        # #     Dim iLine (2)
        # #     assembly_pocket.SetDirection iLine
        # #     set_direction = iLine
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AssemblyPocket(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeBump(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeBump
                | 
                | The Bump feature : an Bump is made up of a body to process and some Bump parameters.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_bump = com_object

    @property
    def body_to_bump(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BodyToBump() As Reference
                | 
                |     Returns or sets the element to Bump.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_bump.BodyToBump)

    @body_to_bump.setter
    def body_to_bump(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_bump.BodyToBump = value.com_object

    @property
    def center_tension(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CenterTension() As RealParam
                | 
                |     Returns or sets the tension center parameter.

        :rtype: RealParam
        """

        return RealParam(self.hybrid_shape_bump.CenterTension)

    @center_tension.setter
    def center_tension(self, real_param: RealParam):
        """
        :param RealParam real_param:
        """

        self.hybrid_shape_bump.CenterTension = real_param.com_object

    @property
    def continuity_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ContinuityType() As long
                | 
                |     Returns or sets the continuity type ..
                |     Legal values: the continuity type is either
                | 
                |      PointContinuity      =0
                |      TangentContinuity    =1 
                |      CurvatureContinuity  =2

        :rtype: int
        """

        return self.hybrid_shape_bump.ContinuityType

    @continuity_type.setter
    def continuity_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_bump.ContinuityType = value

    @property
    def deformation_center(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DeformationCenter() As Reference
                | 
                |     Returns or sets the Deformation Center.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_bump.DeformationCenter)

    @deformation_center.setter
    def deformation_center(self, reference_center: Reference):
        """
        :param Reference reference_center:
        """

        self.hybrid_shape_bump.DeformationCenter = reference_center.com_object

    @property
    def deformation_dir(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DeformationDir() As Reference
                | 
                |     Returns or sets the Deformation Direction.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_bump.DeformationDir)

    @deformation_dir.setter
    def deformation_dir(self, reference_direction: Reference):
        """
        :param Reference reference_direction:
        """

        self.hybrid_shape_bump.DeformationDir = reference_direction.com_object

    @property
    def deformation_dist(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DeformationDist() As Length
                | 
                |     Returns the translate distance (CATIA Parameter).
                |     Note: Distance value is set or retrieve trough a Literaql
                |     parameter
                |     Parameters are value are given in the Part Unit
                |     Example : if Part Unit for dimensions is mm: for 1 mmm, oDefDist.Value will return 1.000

        :rtype: Length
        """

        return Length(self.hybrid_shape_bump.DeformationDist)

    @deformation_dist.setter
    def deformation_dist(self, length: Length):
        """
        :param Length length:
        """

        self.hybrid_shape_bump.DeformationDist = length.com_object

    @property
    def deformation_dist_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DeformationDistValue() As double
                | 
                |     Returns or sets the Deformation distance (double) .
                |     Note: Distance value is expressed in MKS = Meters
                |     Example to set up 1mm , use .001

        :rtype: float
        """

        return self.hybrid_shape_bump.DeformationDistValue

    @deformation_dist_value.setter
    def deformation_dist_value(self, value: float):
        """
        :param float value:
        """

        self.hybrid_shape_bump.DeformationDistValue = value

    @property
    def limit_curve(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property LimitCurve() As Reference
                | 
                |     Returns or sets the limit curve.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_bump.LimitCurve)

    @limit_curve.setter
    def limit_curve(self, reference_curve: Reference):
        """
        :param Reference reference_curve:
        """

        self.hybrid_shape_bump.LimitCurve = reference_curve.com_object

    @property
    def projection_dir(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ProjectionDir() As Reference
                | 
                |     Returns or sets the limit curve.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_bump.ProjectionDir)

    @projection_dir.setter
    def projection_dir(self, reference_projection_direction: Reference):
        """
        :param Reference reference_projection_direction:
        """

        self.hybrid_shape_bump.ProjectionDir = reference_projection_direction.com_object

    def __repr__(self):
        return f'HybridShapeBump(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_fastener_interfaces.fastener import Fastener
from pycatia.system_interfaces.any_object import AnyObject


class DnbFastenerNewMfgPosServices(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBFastenerNewMfgPosServices

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dnb_fastener_new_mfg_pos_services = com_object

    def get_flagged_fasteners(self, o_fastener_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetFlaggedFasteners(CATSafeArrayVariant
                | oFastenerArray)
                | 
                |     Gets List of flagged DELMIAFasteners. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerNewMfgPosServices")
                |     myObject.GetFlaggedFasteners ArrayFastener

        :param tuple o_fastener_array:
        :rtype: None
        """
        return self.dnb_fastener_new_mfg_pos_services.GetFlaggedFasteners(o_fastener_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_flagged_fasteners'
        # # vba_code = """
        # # Public Function get_flagged_fasteners(dnb_fastener_new_mfg_pos_services)
        # #     Dim oFastenerArray (2)
        # #     dnb_fastener_new_mfg_pos_services.GetFlaggedFasteners oFastenerArray
        # #     get_flagged_fasteners = oFastenerArray
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_number_of_flagged_fasteners(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfFlaggedFasteners() As long
                | 
                |     Gets number of flagged DELMIAFasteners. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerNewMfgPosServices")
                |     NbFastener = myObject.GetNumberOfFlaggedFasteners

        :rtype: int
        """
        return self.dnb_fastener_new_mfg_pos_services.GetNumberOfFlaggedFasteners()

    def set_flag(self, i_fastener: Fastener) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFlag(Fastener iFastener)
                | 
                |     flags a specified DELMIAFastener to create a new manufacturing fastener in
                |     its place. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerNewMfgPosServices")
                |     myObject.SetFlag MyFastener always returns S_OK even the function is not successful.
                |     For example the fastener is already flagged.

        :param Fastener i_fastener:
        :rtype: None
        """
        return self.dnb_fastener_new_mfg_pos_services.SetFlag(i_fastener.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_flag'
        # # vba_code = """
        # # Public Function set_flag(dnb_fastener_new_mfg_pos_services)
        # #     Dim iFastener (2)
        # #     dnb_fastener_new_mfg_pos_services.SetFlag iFastener
        # #     set_flag = iFastener
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_flag_on_fasteners(self, i_fastener_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFlagOnFasteners(CATSafeArrayVariant iFastenerArray)
                | 
                |     flags a list of DELMIAFasteners to create new manufacturing fasteners in
                |     their place. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerNewMfgPosServices")
                |     myObject.SetFlagOnFasteners ArrayFastener always returns S_OK even the function is not successful.
                |     For example the fasteners are already flagged.

        :param tuple i_fastener_array:
        :rtype: None
        """
        return self.dnb_fastener_new_mfg_pos_services.SetFlagOnFasteners(i_fastener_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_flag_on_fasteners'
        # # vba_code = """
        # # Public Function set_flag_on_fasteners(dnb_fastener_new_mfg_pos_services)
        # #     Dim iFastenerArray (2)
        # #     dnb_fastener_new_mfg_pos_services.SetFlagOnFasteners iFastenerArray
        # #     set_flag_on_fasteners = iFastenerArray
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def unset_flag(self, i_fastener: Fastener) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetFlag(Fastener iFastener)
                | 
                |     unflags a flagged DELMIAFastener to create a new manufacturing fastener in
                |     its place. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerNewMfgPosServices")
                |     myObject.UnsetFlag MyFastener always returns S_OK even the function is not successful.
                |     For example the fastener is not flagged.

        :param Fastener i_fastener:
        :rtype: None
        """
        return self.dnb_fastener_new_mfg_pos_services.UnsetFlag(i_fastener.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'unset_flag'
        # # vba_code = """
        # # Public Function unset_flag(dnb_fastener_new_mfg_pos_services)
        # #     Dim iFastener (2)
        # #     dnb_fastener_new_mfg_pos_services.UnsetFlag iFastener
        # #     unset_flag = iFastener
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def unset_flag_on_fasteners(self, i_fastener_array: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnsetFlagOnFasteners(CATSafeArrayVariant
                | iFastenerArray)
                | 
                |     unflags a list of DELMIAFasteners to create new manufacturing fasteners in
                |     their place. * 
                | 
                | Example:
                |     Set myObject = CATIA.GetItem("DNBFastenerNewMfgPosServices")
                |     myObject.UnsetFlagOnFasteners ArrayFastener always returns S_OK even the function is not
                |     successful. For example the fasteners are not flagged.

        :param tuple i_fastener_array:
        :rtype: None
        """
        return self.dnb_fastener_new_mfg_pos_services.UnsetFlagOnFasteners(i_fastener_array)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'unset_flag_on_fasteners'
        # # vba_code = """
        # # Public Function unset_flag_on_fasteners(dnb_fastener_new_mfg_pos_services)
        # #     Dim iFastenerArray (2)
        # #     dnb_fastener_new_mfg_pos_services.UnsetFlagOnFasteners iFastenerArray
        # #     unset_flag_on_fasteners = iFastenerArray
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DnbFastenerNewMfgPosServices(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.knowledge_interfaces.parameters import Parameters
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.knowledge_interfaces.parameter_sets import ParameterSets

class ParameterSet(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ParameterSet
                | 
                | Represents parameter set.
                | It is the node that contains user parameters.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.parameter_set = com_object

    @property
    def all_parameters(self) -> list:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help
                | AllParameters
                | o Property AllParameters() As Parameters
                |
                | Returns all parameters under this set of parameter.
                | Parameters:

        :rtype: Parameters
        """
        from .parameter import Parameter
        items = []
        for i in range(0, self.parameter_set.AllParameters.Count):
            items.append(Parameter(self.parameter_set.AllParameters.Item(i + 1)))
        return items

    @property
    def direct_parameters(self) -> Parameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DirectParameters() As Parameters (Read Only)
                | 
                |     Returns directly aggregated parameters.

        :rtype: Parameters
        """

        return Parameters(self.parameter_set.DirectParameters)

    @property
    def parameter_sets(self) -> 'ParameterSets':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ParameterSets() As ParameterSets (Read Only)
                | 
                |     Returns the children parameter sets.

        :rtype: ParameterSets
        """
        from pycatia.knowledge_interfaces.parameter_sets import ParameterSets
        return ParameterSets(self.parameter_set.ParameterSets)

    def __repr__(self):
        return f'ParameterSet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_boundary_conditions import ABQBoundaryConditions
from pycatia.abq_automation_interfaces.abq_loads import ABQLoads
from pycatia.abq_automation_interfaces.abq_step import ABQStep
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product


class ABQFrequencyStep(ABQStep):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQStep
                |                         ABQFrequencyStep
                | 
                | Represents an Abaqus frequency step (ABQFrequencyStep) object.
                | Role: Access an Abaqus frequency step object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_frequency_step = com_object

    @property
    def boundary_conditions(self) -> ABQBoundaryConditions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BoundaryConditions() As ABQBoundaryConditions (Read
                | Only)
                | 
                |     Returns the ABQBoundaryConditions container associated with the
                |     step.
                | 
                |     Example:
                |         This example retrieves the ABQBoundaryConditions container
                |         abqBCs.
                | 
                |          Dim abqFreqStep As ABQFrequencyStep 
                |          Dim abqBCs As ABQBoundaryConditions
                |          Set abqBCs = abqFreqStep.BoundaryConditions

        :rtype: ABQBoundaryConditions
        """

        return ABQBoundaryConditions(self.abq_frequency_step.BoundaryConditions)

    @property
    def description(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Description() As CATBSTR
                | 
                |     Returns or sets the description of the Abaqus general static
                |     step.
                | 
                |     Returns:
                |         The description of the Abaqus general static step.

        :rtype: str
        """

        return self.abq_frequency_step.Description

    @description.setter
    def description(self, value: str):
        """
        :param str value:
        """

        self.abq_frequency_step.Description = value

    @property
    def eigensolver_value(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EigensolverValue() As short
                | 
                |     Returns or sets Eigensolver Value.
                | 
                |     Returns:
                |         The Eigensolver Value.
                | 
                |           
                |         Legal values:
                |          1 - Lanczos.
                |          2 - AMS.
                |          
                | 
                |         Example:
                |             This example sets eigensolver as Lanczos
                |             abqFreqStep
                | 
                |              abqFreqStep.EigensolverValue = 1

        :rtype: int
        """

        return self.abq_frequency_step.EigensolverValue

    @eigensolver_value.setter
    def eigensolver_value(self, value: int):
        """
        :param int value:
        """

        self.abq_frequency_step.EigensolverValue = value

    @property
    def frequency_shift(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FrequencyShift() As short
                | 
                |     Returns or sets frequency shift value.
                | 
                |     Returns:
                |         The frequency shift value.
                | 
                |         Example:
                |             This example sets the maximum frequency for
                |             abqFreqStep
                | 
                |              abqFreqStep.FrequencyShift = 10

        :rtype: int
        """

        return self.abq_frequency_step.FrequencyShift

    @frequency_shift.setter
    def frequency_shift(self, value: int):
        """
        :param int value:
        """

        self.abq_frequency_step.FrequencyShift = value

    @property
    def loads(self) -> ABQLoads:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Loads() As ABQLoads (Read Only)
                | 
                |     Returns the ABQLoads container associated with the step.
                | 
                |     Example:
                |         The following example retrieves the ABQLoads container
                |         abqLoads:
                | 
                |          Dim abqFreqStep As ABQFrequencyStep 
                |          Dim abqLoads As ABQLoads
                |          Set abqLoads = abqFreqStep.Loads

        :rtype: ABQLoads
        """

        return ABQLoads(self.abq_frequency_step.Loads)

    @property
    def maximum_frequency(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaximumFrequency() As short
                | 
                |     Returns or sets maximum frequency value.
                | 
                |     Returns:
                |         The maximum frequency value.
                | 
                |         Example:
                |             This example sets the maximum frequency for
                |             abqFreqStep
                | 
                |              abqFreqStep.MaximumFrequency = 100

        :rtype: int
        """

        return self.abq_frequency_step.MaximumFrequency

    @maximum_frequency.setter
    def maximum_frequency(self, value: int):
        """
        :param int value:
        """

        self.abq_frequency_step.MaximumFrequency = value

    @property
    def minimum_frequency(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MinimumFrequency() As short
                | 
                |     Returns or sets minimum frequency value.
                | 
                |     Returns:
                |         The minimum frequency value.
                | 
                |         Example:
                |             This example sets the minimum frequency for
                |             abqFreqStep
                | 
                |              abqFreqStep.MinimumFrequency = 10

        :rtype: int
        """

        return self.abq_frequency_step.MinimumFrequency

    @minimum_frequency.setter
    def minimum_frequency(self, value: int):
        """
        :param int value:
        """

        self.abq_frequency_step.MinimumFrequency = value

    @property
    def normalization_value(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NormalizationValue() As short
                | 
                |     Returns or sets Normalization Value.
                | 
                |     Returns:
                |         The Normalization Value.
                | 
                |           
                |         Legal values:
                |          1 - Displacement.
                |          2 - Mass.
                |          
                | 
                |         Example:
                |             This example sets Normalization as Displacement
                |             abqFreqStep
                | 
                |              abqFreqStep.NormalizationValue = 1

        :rtype: int
        """

        return self.abq_frequency_step.NormalizationValue

    @normalization_value.setter
    def normalization_value(self, value: int):
        """
        :param int value:
        """

        self.abq_frequency_step.NormalizationValue = value

    @property
    def requested_modes_option(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RequestedModesOption() As short
                | 
                |     Sets or returns the requested modes option.
                | 
                |     Returns:
                |         The option of requested modes.
                | 
                |           
                |         Legal values:
                |          ABQ_ALL - All modes.
                |          ABQ_VALUE - Specify the no of modes to be requested.
                |          
                | 
                |         Example:
                |             This example sets the requested modes option for abqFreqStep job to
                |             every increment.
                | 
                |              abqFreqStep.RequestedModesOption = ABQ_ALL

        :return: enum abq_requested_modes_option
        :rtype: int
        """

        return self.abq_frequency_step.RequestedModesOption

    @requested_modes_option.setter
    def requested_modes_option(self, value: int):
        """
        :param int value: enum abq_requested_modes_option
        """

        self.abq_frequency_step.RequestedModesOption = value

    @property
    def requested_modes_value(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RequestedModesValue() As short
                | 
                |     Returns or sets requested modes value. This is only valid if
                |     RestartRequestOption is ABQ_VALUE
                | 
                |     Returns:
                |         The requested modes value.
                | 
                |         Example:
                |             This example sets the requested modes for
                |             abqFreqStep
                | 
                |              abqFreqStep.RequestedModesValue = 10

        :rtype: int
        """

        return self.abq_frequency_step.RequestedModesValue

    @requested_modes_value.setter
    def requested_modes_value(self, value: int):
        """
        :param int value:
        """

        self.abq_frequency_step.RequestedModesValue = value

    @property
    def residual_mode_req_boolean(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ResidualModeReqBoolean() As boolean
                | 
                |     Returns or sets Residual Mode Request Boolean Value.
                | 
                |     Returns:
                |         The Residual Mode Request Boolean Value.

        :rtype: bool
        """

        return self.abq_frequency_step.ResidualModeReqBoolean

    @residual_mode_req_boolean.setter
    def residual_mode_req_boolean(self, value: bool):
        """
        :param bool value:
        """

        self.abq_frequency_step.ResidualModeReqBoolean = value

    @property
    def sim_architecture_req_boolean(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SIMArchitectureReqBoolean() As boolean
                | 
                |     Returns or sets SIM Architecture Request Boolean Value.
                | 
                |     Returns:
                |         The SIM Architecture Request Boolean Value.

        :rtype: bool
        """

        return self.abq_frequency_step.SIMArchitectureReqBoolean

    @sim_architecture_req_boolean.setter
    def sim_architecture_req_boolean(self, value: bool):
        """
        :param bool value:
        """

        self.abq_frequency_step.SIMArchitectureReqBoolean = value

    def add_residual_mode_region(self, i_product: Product, i_support: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddResidualModeRegion(Product iProduct,
                | Reference iSupport)
                | 
                |     Adds the Residual Mode Region.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIAProduct specifying the positioning
                |             object.
                |         iSupport
                |             The CATIAReference specifying the object that is being pointed
                |             to.

        :param Product i_product:
        :param Reference i_support:
        :rtype: None
        """
        return self.abq_frequency_step.AddResidualModeRegion(i_product.com_object, i_support.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_residual_mode_region'
        # # vba_code = """
        # # Public Function add_residual_mode_region(abq_frequency_step)
        # #     Dim iProduct (2)
        # #     abq_frequency_step.AddResidualModeRegion iProduct
        # #     add_residual_mode_region = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_residual_mode_region_dof(self, i_dof: int, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddResidualModeRegionDOF(short iDOF,
                | short iIndex)
                | 
                |     Adds the Residual Mode Region DOF.
                | 
                |     Parameters:
                | 
                |         iDOF
                |             The DOF.
                |         iIndex
                |             The index at which the DOF is being set.

        :param int i_dof:
        :param int i_index:
        :rtype: None
        """
        return self.abq_frequency_step.AddResidualModeRegionDOF(i_dof, i_index)

    def __repr__(self):
        return f'ABQFrequencyStep(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arr_nomenclature import ArrNomenclature
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ArrNomenclatures(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ArrNomenclatures
                | 
                | The collection of UserNomenclature objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ArrNomenclature)
        self.arr_nomenclatures = com_object

    def add_user_nomenclature(
            self,
            i_name: str,
            i_icon_name: str,
            i_class_type: str,
            i_super_type: str
    ) -> ArrNomenclature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddUserNomenclature(CATBSTR iName,
                | CATBSTR iIconName,
                | CATBSTR iClassType,
                | CATBSTR iSuperType) As ArrNomenclature
                | 
                |     Creates a new UserNomenclature and adds it to this collection. The
                |     NomenclatureType of the new UserNomenclature will be "User". The base objects
                |     in the UserDictionary are created when the UserDictionary is
                |     created.
                | 
                |     Parameters:
                | 
                |         iName
                |             The user nomenclature name. 
                |         iIconName
                |             The icon name associated to this nomenclature name.
                |
                |     Returns:
                |         The new UserNomenclature.

        :param str i_name:
        :param str i_icon_name:
        :param str i_class_type:
        :param str i_super_type:
        :rtype: ArrNomenclature
        """
        return ArrNomenclature(
            self.arr_nomenclatures.AddUserNomenclature(
                i_name,
                i_icon_name,
                i_class_type,
                i_super_type
            )
        )

    def item(self, i_index: cat_variant) -> ArrNomenclature:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ArrNomenclature
                | 
                |     Returns the specified item of the collection
                | 
                |     Parameters:
                | 
                |         iItem
                |             The list index (long) or name (CATBSTR) of the member to retrieve.
                |             
                | 
                |     Returns:
                |         The retrieved member object.

        :param cat_variant i_index:
        :rtype: ArrNomenclature
        """
        return ArrNomenclature(self.arr_nomenclatures.Item(i_index))

    def __repr__(self):
        return f'ArrNomenclatures(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_state_interfaces.dnb_3d_state import DNB3DState
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class DNB3DStates(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DNB3DStates
                | 
                | Interface representing the collection of 3D State objects.
                | 
                | Role: Provides access to 3D State objects
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=DNB3DState)
        self.dnb3_d_states = com_object

    @property
    def states_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StatesCount() As long (Read Only)
                | 
                |     Returns the number of 3D State objects in the collection.
                | 
                |     Example:
                |         This example fetches the Number of 3D states in the
                |         collection
                | 
                |          Dim list3DStates as DNB3DStates
                |          Set list3DStates = stateMgt.ListAll3DStates  
                |          stateCount = list3DStates.StatesCount

        :rtype: int
        """

        return self.dnb3_d_states.StatesCount

    def item(self, i_index: cat_variant) -> DNB3DState:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As DNB3DState
                | 
                |     Returns the 3D state object.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index to the item to be returned 
                | 
                |     Returns:
                |         The 3D State object
                | 
                |         Example:
                |             This example returns the first item from the collection 3D
                |             states
                | 
                |              Dim list3DStates as DNB3DStates
                |              Set list3DStates = positionMgt.ListAll3DStates
                |              Dim my3DState As DNB3DState
                |              Set my3DState = list3DStates.Item(1)

        :param cat_variant i_index:
        :rtype: DNB3DState
        """
        return DNB3DState(self.dnb3_d_states.Item(i_index))

    def __repr__(self):
        return f'DNB3DStates(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
from typing import Iterator

from pycatia.navigator_interfaces.marker_3D import Marker3D
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Marker3Ds(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Marker3Ds
                | 
                | A collection of Marker3D objects.
                | 
                | The method Product.GetTechnologicalObject ("Marker3Ds") on the root product
                | retrieves this collection.

    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Marker3D)
        self.marker_3ds = com_object

    def add3_d_text(self, i_text_coordinates: tuple, i_text: str, i_object_coordinates: tuple,
                    i_object: AnyObject) -> Marker3D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add3DText(CATSafeArrayVariant iTextCoordinates,
                | CATBSTR iText,
                | CATSafeArrayVariant iObjectCoordinates,
                | AnyObject iObject) As Marker3D
                | 
                |     Creates a text marker 3D and adds it to the marker 3D collection. The
                |     bottom-left corner of the text is anchored to a given
                |     point.
                | 
                |     Parameters:
                | 
                |         iTextCoordinates
                |             The coordinates of the text anchor point
                | 
                |                 iTextCoordinates(0) is the X coordinate of the text anchor
                |                 point
                |                 iTextCoordinates(1) is the Y coordinate of the text anchor
                |                 point
                |                 iTextCoordinates(2) is the Z coordinate of the text anchor
                |                 point 
                | 
                |         iText
                |             The text 
                |         iObjectCoordinates
                |             The coordinates of the anchor of the marker 3D on the
                |             object
                | 
                |                 iObjectCoordinates(0) is the X coordinate of the object anchor
                |                 point
                |                 iObjectCoordinates(1) is the Y coordinate of the object anchor
                |                 point
                |                 iObjectCoordinates(2) is the Z coordinate of the object anchor
                |                 point 
                | 
                |         iObject
                |             The object which supports the text. 
                | 
                |     Returns:
                |         The created marker 3D 
                |     Example:
                | 
                |              This example creates a new marker 3D in the TheMarker3Ds
                |              collection.
                |             
                | 
                |             Dim NewMarker3DText As Marker3D
                |             Set NewMarker3DText = TheMarker3Ds.Add3DText(Position1, "example", Position2, Product2)

        :param tuple i_text_coordinates:
        :param str i_text:
        :param tuple i_object_coordinates:
        :param AnyObject i_object:
        :rtype: Marker3D
        """
        return Marker3D(
            self.marker_3ds.Add3DText(i_text_coordinates, i_text, i_object_coordinates, i_object.com_object))

    def item(self, i_index: cat_variant) -> Marker3D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As Marker3D
                | 
                |     Returns a marker 3D using its index from the Marker3Ds
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the marker 3D to retrieve from the
                |             collection of Marker3Ds. As a numerics, this index is the rank of the marker 3D
                |             in the collection. The index of the first Marker3D in the collection is 1, and
                |             the index of the last Marker3D is Count. As a string, it is the name you
                |             assigned to the Marker3D. 
                | 
                |     Returns:
                |         The retrieved marker 3D 
                |     Example:
                | 
                |              This example retrieves in ThisMarker3D the ninth marker
                |              3D,
                |             and in ThatMarker3D the marker 3D named
                |             Marker3D3 from the TheMarker3Ds collection. 
                |             
                | 
                |             Dim ThisMarker3D As Marker3D
                |             Set ThisMarker3D = TheMarker3Ds.Item(9)
                |             Dim ThatMarker3D As Marker3D
                |             Set ThatMarker3D = TheMarker3Ds.Item("Marker3D3")

        :param cat_variant i_index:
        :rtype: Marker3D
        """
        return Marker3D(self.marker_3ds.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a marker 3D from the Marker3Ds collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the marker 3D to retrieve from the
                |             collection of Marker3Ds. As a numerics, this index is the rank of the marker 3D
                |             in the collection. The index of the first marker 3D in the collection is 1, and
                |             the index of the last marker 3D is Count. As a string, it is the name you
                |             assigned to the marker 3D. 
                | 
                |     Example:
                | 
                |              The following example removes the tenth marker 3D and the marker
                |              3D named
                |             Marker3D2 from the TheMarker3Ds collection.
                |             
                | 
                |             TheMarker3Ds.Remove(10)
                |             TheMarker3Ds.Remove("Marker3D2")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.marker_3ds.Remove(i_index)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(marker_3ds)
        # #     Dim iIndex (2)
        # #     marker_3ds.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __getitem__(self, n: int) -> Marker3D:
        if (n + 1) > self.count:
            raise StopIteration

        return Marker3D(self.marker_3ds.Item(n + 1))

    def __iter__(self) -> Iterator[Marker3D]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'Marker3Ds(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_body_element import SWKBodyElement
from pycatia.dnb_human_modeling_interfaces.swk_manikin import SWKManikin
from pycatia.dnb_human_modeling_interfaces.swk_manikin_part import SWKManikinPart
from pycatia.dnb_human_modeling_interfaces.swk_segment import SWKSegment
from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject


class SWKIKConstraint(SWKManikinPart):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBHumanModelingInterfaces.SWKManikinPart
                |                         SWKIKConstraint
                | 
                | This interface manages the constraint of the manikin.
                | It provides access to the constraints data (ID, EndEffector,
                | StartSegment,...)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swkik_constraint = com_object

    @property
    def active(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Active() As boolean
                | 
                |     Returns or sets the constraint activity.
                |     A constraint being active means that the constraint is taken
                |     into account during the resolution.
                | 
                |     If the constraint is not active,then it is ignored during the resolution.

        :rtype: bool
        """

        return self.swkik_constraint.Active

    @active.setter
    def active(self, value: bool):
        """
        :param bool value:
        """

        self.swkik_constraint.Active = value

    @property
    def angle_criteria(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AngleCriteria() As double
                | 
                |     Returns or sets the angle criteria that will be used to evaluate success or
                |     failure of the constraint resolution. If, after resolution, the agle between
                |     the constraint and the target is lower than the criteria, then the constraint
                |     will be considered resolved. This criteria must be specified in radians.

        :rtype: float
        """

        return self.swkik_constraint.AngleCriteria

    @angle_criteria.setter
    def angle_criteria(self, value: float):
        """
        :param float value:
        """

        self.swkik_constraint.AngleCriteria = value

    @property
    def angle_to_target(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AngleToTarget() As double (Read Only)
                | 
                |     Returns the angle (in radians) from the constraint end effector to the
                |     target.

        :rtype: float
        """

        return self.swkik_constraint.AngleToTarget

    @property
    def distance_criteria(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DistanceCriteria() As double
                | 
                |     Returns or sets the distance criteria that will be used to evaluate success
                |     or failure of the constraint resolution. If, after resolution, the distance
                |     between the constraint and the target is lower than the criteria, then the
                |     constraint will be considered resolved. This criteria must be specified in
                |     millimeters.

        :rtype: float
        """

        return self.swkik_constraint.DistanceCriteria

    @distance_criteria.setter
    def distance_criteria(self, value: float):
        """
        :param float value:
        """

        self.swkik_constraint.DistanceCriteria = value

    @property
    def distance_to_target(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DistanceToTarget() As double (Read Only)
                | 
                |     Returns the distance (in mm) from the constraint end effector to the
                |     target.

        :rtype: float
        """

        return self.swkik_constraint.DistanceToTarget

    @property
    def end_effector(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EndEffector() As CATBSTR
                | 
                |     Returns or sets the end effector of the IK chain of the constraint. The
                |     string in this property is the short name of the last segment (or line of
                |     sight) to be driven by this constraint

        :rtype: str
        """

        return self.swkik_constraint.EndEffector

    @end_effector.setter
    def end_effector(self, value: str):
        """
        :param str value:
        """

        self.swkik_constraint.EndEffector = value

    @property
    def identifier(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Identifier() As CATBSTR (Read Only)
                | 
                |     Returns the identifier(ID) of the constraint.

        :rtype: str
        """

        return self.swkik_constraint.Identifier

    @property
    def is_success(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IsSuccess() As boolean (Read Only)
                | 
                |     Returns whether the resolution of this constraint is a success or a
                |     failure, given the current criteria.

        :rtype: bool
        """

        return self.swkik_constraint.IsSuccess

    @property
    def manikin(self) -> SWKManikin:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Manikin() As SWKManikin (Read Only)
                | 
                |     Returns the manikin which owns this IK constraint.

        :rtype: SWKManikin
        """

        return SWKManikin(self.swkik_constraint.Manikin)

    @property
    def priority(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Priority() As long
                | 
                |     Returns or sets the priority of the constraint.
                |     When using that property, the number returned or set
                |     is an integer and must be between 1 and 4 inclusive.
                |     The lower the priority, the more prioritary the constraint becomes.

        :rtype: int
        """

        return self.swkik_constraint.Priority

    @priority.setter
    def priority(self, value: int):
        """
        :param int value:
        """

        self.swkik_constraint.Priority = value

    @property
    def rotation_offset_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RotationOffsetAngle() As double
                | 
                |     Returns or sets the rotation offset angle for the 3D plane
                |     constraint.
                |     This rotation offset angle(rad) is used to adjust 3D plane
                |     constraint.
                |     When using that property, the number returned or set
                |     must be between -PI and PI inclusive.

        :rtype: float
        """

        return self.swkik_constraint.RotationOffsetAngle

    @rotation_offset_angle.setter
    def rotation_offset_angle(self, value: float):
        """
        :param float value:
        """

        self.swkik_constraint.RotationOffsetAngle = value

    @property
    def start_segment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartSegment() As CATBSTR
                | 
                |     Returns or sets the first segment of the body to be driven
                |     by this constraint.

        :rtype: str
        """

        return self.swkik_constraint.StartSegment

    @start_segment.setter
    def start_segment(self, value: str):
        """
        :param str value:
        """

        self.swkik_constraint.StartSegment = value

    @property
    def transfer_with_target(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TransferWithTarget() As boolean
                | 
                |     Returns or sets the Transfer With Target property.

        :rtype: bool
        """

        return self.swkik_constraint.TransferWithTarget

    @transfer_with_target.setter
    def transfer_with_target(self, value: bool):
        """
        :param bool value:
        """

        self.swkik_constraint.TransferWithTarget = value

    @property
    def user_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UserType() As CATBSTR (Read Only)
                | 
                |     Returns the user type of the constraint. The user type returned will be one
                |     of the following: ("Contact", "Coincidence", "Fix", or "FixOn"),

        :rtype: str
        """

        return self.swkik_constraint.UserType

    def get_constraint_element(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConstraintElement() As CATBaseDispatch
                | 
                |     Returns a reference to the target object of the constraint (if any).

        :rtype: AnyObject
        """
        return self.swkik_constraint.GetConstraintElement()

    def get_end_effector(self) -> SWKBodyElement:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetEndEffector() As SWKBodyElement
                | 
                |     Returns the end effector of the IK chain of the constraint.

        :rtype: SWKBodyElement
        """
        return SWKBodyElement(self.swkik_constraint.GetEndEffector())

    def get_start_segment(self) -> SWKSegment:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStartSegment() As SWKSegment
                | 
                |     Returns the start segment of the IK chain of the constraint.

        :rtype: SWKSegment
        """
        return SWKSegment(self.swkik_constraint.GetStartSegment())

    def get_target_line(self, po_target_line_coord: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTargetLine(CATSafeArrayVariant poTargetLineCoord)
                | 
                |     Get the target points coordinates of a line This method
                |     retrieves the origin point coordinates as (x, y, z) data
                |     and the direction value of a line.
                | 
                |     Parameters:
                | 
                |         poTargetLineCoord
                |             The array of 6 data containing target point coordinates as x, y, z
                |             respectively and the x, y, z direction values for the target line.

        :param tuple po_target_line_coord:
        :rtype: None
        """
        return self.swkik_constraint.GetTargetLine(po_target_line_coord)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_target_line'
        # # vba_code = """
        # # Public Function get_target_line(swkik_constraint)
        # #     Dim poTargetLineCoord (2)
        # #     swkik_constraint.GetTargetLine poTargetLineCoord
        # #     get_target_line = poTargetLineCoord
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_target_plane(self, po_target_plane_coord: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTargetPlane(CATSafeArrayVariant poTargetPlaneCoord)
                | 
                |     Get the target points coordinates of a line This method retrieves the
                |     origin point coordinates as (x, y, z) data and the direction value of a
                |     line.
                | 
                |     Parameters:
                | 
                |         poTargetLineCoord
                |             The array of 9 data containing origin point coordinates as x, y, z,
                |             the first normalized direction as x, y, z coordinates and the x, y, z
                |             ortho-normalized direction values for the target plane.

        :param tuple po_target_plane_coord:
        :rtype: None
        """
        return self.swkik_constraint.GetTargetPlane(po_target_plane_coord)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_target_plane'
        # # vba_code = """
        # # Public Function get_target_plane(swkik_constraint)
        # #     Dim poTargetPlaneCoord (2)
        # #     swkik_constraint.GetTargetPlane poTargetPlaneCoord
        # #     get_target_plane = poTargetPlaneCoord
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_target_point(self, po_target_pt_coord: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTargetPoint(CATSafeArrayVariant poTargetPtCoord)
                | 
                |     Get the target point coordinates. This method retrieves the target point
                |     coordinates as (x, y, z) data under an array form.
                | 
                |     Parameters:
                | 
                |         poTargetPtCoord
                |             The array containing target point coordinates as x, y, z
                |             respectively, the x coordinate being the first data in the array.

        :param tuple po_target_pt_coord:
        :rtype: None
        """
        return self.swkik_constraint.GetTargetPoint(po_target_pt_coord)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_target_point'
        # # vba_code = """
        # # Public Function get_target_point(swkik_constraint)
        # #     Dim poTargetPtCoord (2)
        # #     swkik_constraint.GetTargetPoint poTargetPtCoord
        # #     get_target_point = poTargetPtCoord
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reset_target(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetTarget()
                | 
                |     Reset the offset of the target object (i.e. set the offset
                |     to the end effector's current position).

        :rtype: None
        """
        return self.swkik_constraint.ResetTarget()

    def set_constraint_element(self, pi_constraint_element: AnyObject, pi_constraint_type: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConstraintElement(CATBaseDispatch
                | piConstraintElement,
                | CATBSTR piConstraintType)
                | 
                |     Set the target object to follow. This method establishes a part relation
                |     between the end effector and an object to follow.
                | 
                |     Parameters:
                | 
                |         piConstraintElement
                |             A reference to the target object
                |             This target object can be either a wireframe 
                | 
                |         GeometricElement object such as a plane or a line, or a boundary
                |         representation object such as a face, a vertex or an edge. In the case of a
                |         'Fix on' constraint, the target object must be the product ( CATIAProduct)
                |         associated with the constraint. 
                |     piConstraintType
                |         The type of the constraint.
                |         This parameter can take the following values: "Coincidence", "Contact",
                |         "Contact2D", "Contact3D", "FixPositon", "FixOrientation",
                |         "FixPositonAndOrientation", "FixOnPositon", "FixOnOrientation" and
                |         "FixOnPositonAndOrientation".

        :param AnyObject pi_constraint_element:
        :param str pi_constraint_type:
        :rtype: None
        """
        return self.swkik_constraint.SetConstraintElement(pi_constraint_element.com_object, pi_constraint_type)

    def set_target_line(
            self,
            pi_object: Reference,
            pi_start_point_x: float,
            pi_start_point_y: float,
            pi_start_point_z: float,
            pi_end_point_x: float,
            pi_end_point_y: float,
            pi_end_point_z: float,
            pi_constraint_type: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTargetLine(Reference piObject,
                | double piStartPointX,
                | double piStartPointY,
                | double piStartPointZ,
                | double piEndPointX,
                | double piEndPointY,
                | double piEndPointZ,
                | CATBSTR piConstraintType)
                | 
                |     Set the target line to follow. This method establishes a contact or
                |     coincidence constraint between the end effector and the
                |     line.
                | 
                |     Parameters:
                | 
                |         piConstraintElement
                |             A reference to the target object
                |             This target object must be the product (
                | 
                |         CATIAProduct) associated with the constraint. 
                |     piStartPointX
                |         The x coordinate of the start point of the line, relatively to the
                |         father object. 
                |     piStartPointY
                |         The y coordinate of the start point of the line, relatively to the
                |         father object. 
                |     piStartPointZ
                |         The z coordinate of the start point of the line, relatively to the
                |         father object. 
                |     piEndPointX
                |         The x coordinate of the end point of the line, relatively to the father
                |         object. 
                |     piEndPointY
                |         The y coordinate of the end point of the line, relatively to the father
                |         object. 
                |     piEndPointZ
                |         The z coordinate of the end point of the line, relatively to the father
                |         object. 
                |     piConstraintType
                |         The type of the constraint.
                |         This parameter can take the values "Contact", "Contact2D", "Contact3D"
                |         or "Coincidence".

        :param Reference pi_object:
        :param float pi_start_point_x:
        :param float pi_start_point_y:
        :param float pi_start_point_z:
        :param float pi_end_point_x:
        :param float pi_end_point_y:
        :param float pi_end_point_z:
        :param str pi_constraint_type:
        :rtype: None
        """
        return self.swkik_constraint.SetTargetLine(
            pi_object.com_object,
            pi_start_point_x,
            pi_start_point_y,
            pi_start_point_z,
            pi_end_point_x,
            pi_end_point_y,
            pi_end_point_z,
            pi_constraint_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_target_line'
        # # vba_code = """
        # # Public Function set_target_line(swkik_constraint)
        # #     Dim piObject (2)
        # #     swkik_constraint.SetTargetLine piObject
        # #     set_target_line = piObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_target_plane(
            self,
            pi_object: Reference,
            pi_origin_x: float,
            pi_origin_y: float,
            pi_origin_z: float,
            pi_normal_x: float,
            pi_normal_y: float,
            pi_normal_z: float,
            pi_constraint_type: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTargetPlane(Reference piObject,
                | double piOriginX,
                | double piOriginY,
                | double piOriginZ,
                | double piNormalX,
                | double piNormalY,
                | double piNormalZ,
                | CATBSTR piConstraintType)
                | 
                |     Set the target plane to follow. This method establishes a contact or
                |     coincidence constraint between the end effector and the
                |     plane.
                | 
                |     Parameters:
                | 
                |         piConstraintElement
                |             A reference to the target object
                |             This target object must be the product (
                | 
                |         CATIAProduct) associated with the constraint. 
                |     piOriginX
                |         The x coordinate of the origin of the plane, relatively to the father
                |         object. 
                |     piOriginY
                |         The y coordinate of the origin of the plane, relatively to the father
                |         object. 
                |     piOriginZ
                |         The z coordinate of the origin of the plane, relatively to the father
                |         object. 
                |     piNormalX
                |         The x coordinate of the normal vector of the plane, relatively to the
                |         father object. 
                |     piNormalY
                |         The y coordinate of the normal vector of the plane, relatively to the
                |         father object. 
                |     piNormalZ
                |         The z coordinate of the normal vector of the plane, relatively to the
                |         father object. 
                |     piConstraintType
                |         The type of the constraint.
                |         This parameter can take the values "Contact", "Contact2D", "Contact3D"
                |         or "Coincidence".

        :param Reference pi_object:
        :param float pi_origin_x:
        :param float pi_origin_y:
        :param float pi_origin_z:
        :param float pi_normal_x:
        :param float pi_normal_y:
        :param float pi_normal_z:
        :param str pi_constraint_type:
        :rtype: None
        """
        return self.swkik_constraint.SetTargetPlane(
            pi_object.com_object,
            pi_origin_x,
            pi_origin_y,
            pi_origin_z,
            pi_normal_x,
            pi_normal_y,
            pi_normal_z,
            pi_constraint_type
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_target_plane'
        # # vba_code = """
        # # Public Function set_target_plane(swkik_constraint)
        # #     Dim piObject (2)
        # #     swkik_constraint.SetTargetPlane piObject
        # #     set_target_plane = piObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_target_point(self, pi_object: Reference, pi_coord_x: float, pi_coord_y: float, pi_coord_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTargetPoint(Reference piObject,
                | double piCoordX,
                | double piCoordY,
                | double piCoordZ)
                | 
                |     Set the target point to follow. This method establishes a contact
                |     constraint between the end effector and the point.
                | 
                |     Parameters:
                | 
                |         piConstraintElement
                |             A reference to the target object
                |             This target object must be the product (
                | 
                |         CATIAProduct) associated with the constraint. 
                |     piCoordX
                |         The x coordinate of the point, relatively to the father object.
                |         
                |     piCoordY
                |         The y coordinate of the point, relatively to the father object.
                |         
                |     piCoordZ
                |         The z coordinate of the point, relatively to the father object.

        :param Reference pi_object:
        :param float pi_coord_x:
        :param float pi_coord_y:
        :param float pi_coord_z:
        :rtype: None
        """
        return self.swkik_constraint.SetTargetPoint(pi_object.com_object, pi_coord_x, pi_coord_y, pi_coord_z)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_target_point'
        # # vba_code = """
        # # Public Function set_target_point(swkik_constraint)
        # #     Dim piObject (2)
        # #     swkik_constraint.SetTargetPoint piObject
        # #     set_target_point = piObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SWKikConstraint(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.plane import Plane
from pycatia.in_interfaces.reference import Reference


class HybridShapePlaneMean(Plane):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Plane
                |                             HybridShapePlaneMean
                | 
                | Represents the hybrid shape mean plane feature object.
                | Role: To access the data of the hybrid shape mean plane feature object. This
                | data includes:
                | 
                |     The list of points
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapePlaneMean
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_plane_mean = com_object

    def add_point(self, i_passing_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub AddPoint(Reference iPassingPoint)
                | 
                |     Adds a point to the mean plane.
                | 
                |     Parameters:
                | 
                |         iPassingPoint
                |             The point to add
                | 
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): Vertex.

        :param Reference i_passing_point:
        :rtype: None
        """
        return self.hybrid_shape_plane_mean.AddPoint(i_passing_point.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_point'
        # # vba_code = """
        # # Public Function add_point(hybrid_shape_plane_mean)
        # #     Dim iPassingPoint (2)
        # #     hybrid_shape_plane_mean.AddPoint iPassingPoint
        # #     add_point = iPassingPoint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_point(self, i_rank: int, o_passing_point: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub GetPoint(long iRank,
                | Reference oPassingPoint)
                | 
                |     Retrieves the point at a given position.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the point to retrieve 
                |         oPassingPoint
                |             The point retrieved at this rank

        :param int i_rank:
        :param Reference o_passing_point:
        :rtype: None
        """
        return self.hybrid_shape_plane_mean.GetPoint(i_rank, o_passing_point.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_point'
        # # vba_code = """
        # # Public Function get_point(hybrid_shape_plane_mean)
        # #     Dim iRank (2)
        # #     hybrid_shape_plane_mean.GetPoint iRank
        # #     get_point = iRank
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_pos(self, i_point: Reference) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetPos(Reference iPoint) As long
                | 
                |     Gets the position of an element in the list.
                | 
                |     Parameters:
                | 
                |         iPoint
                |             point 
                |         oPos
                |             position of point

        :param Reference i_point:
        :rtype: int
        """
        return self.hybrid_shape_plane_mean.GetPos(i_point.com_object)

    def get_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSize() As long
                | 
                |     Gets the size of the list (number of points).
                | 
                |     Parameters:
                | 
                |         oSize
                |             position of point

        :rtype: int
        """
        return self.hybrid_shape_plane_mean.GetSize()

    def remove_all(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveAll()
                | 
                |     Removes all elements in the list of points.

        :rtype: None
        """
        return self.hybrid_shape_plane_mean.RemoveAll()

    def remove_element(self, i_rank: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub RemoveElement(long iRank)
                | 
                |     Removes a point in the list.
                | 
                |     Parameters:
                | 
                |         iRank
                |             The rank of the point to remove

        :param int i_rank:
        :rtype: None
        """
        return self.hybrid_shape_plane_mean.RemoveElement(i_rank)

    def replace_point_at_position(self, i_point: Reference, i_pos: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub ReplacePointAtPosition(Reference iPoint,
                | long iPos)
                | 
                |     Replaces a point in the list at the given position.
                | 
                |     Parameters:
                | 
                |         oPoint
                |             point 
                |         iPos
                |             position of point

        :param Reference i_point:
        :param int i_pos:
        :rtype: None
        """
        return self.hybrid_shape_plane_mean.ReplacePointAtPosition(i_point.com_object, i_pos)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'replace_point_at_position'
        # # vba_code = """
        # # Public Function replace_point_at_position(hybrid_shape_plane_mean)
        # #     Dim iPoint (2)
        # #     hybrid_shape_plane_mean.ReplacePointAtPosition iPoint
        # #     replace_point_at_position = iPoint
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapePlaneMean(name="{self.name}")'
